# BiasProbe: Probing What Llamas Really Think

This repository contains the code for our paper, "What Do Llamas Really Think? Revealing Preference Biases in Language Model Representations."

## Getting Started

1. Install the codebase:
```python
pip install biasprobe
```

2. 
